# t-cup - robust linear regression

This package presents a statistical model for robust linear regression where
both independent and dependent variables are measured with measurement error.

This code is bundled with [XDGMM](https://github.com/tholoien/XDGMM), a Python
package implementing the
[extreme deconvolution algorithm](https://arxiv.org/abs/0905.2979).
